# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: a42/data/pointcloud.proto
# plugin: python-betterproto
from dataclasses import dataclass

import betterproto


@dataclass
class PointCloud(betterproto.Message):
    cartesian: bytes = betterproto.bytes_field(1)
    intensity: bytes = betterproto.bytes_field(2)
    ambient: bytes = betterproto.bytes_field(3)
    velocity: bytes = betterproto.bytes_field(4)
    reflectivity: bytes = betterproto.bytes_field(5)
    timestamp_offset: bytes = betterproto.bytes_field(6)
    channel_id: bytes = betterproto.bytes_field(7)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: a42/sensors/camera.proto, a42/sensors/lidar.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto

from . import common
from . import data
from . import label


class LaserName(betterproto.Enum):
    """Identifiziert, welcher LiDAR das war"""

    UNKNOWN_NAME = 0
    WIM_HOR = 1
    ANPR_HOR = 2
    AMPEL_HOR = 3
    WIM_VER = 4
    ANPR_VER = 5
    AMPEL_VER = 6
    CLASS_QB2 = 7
    CLASS_OS0 = 8
    CLASS_AERIES_II = 9


@dataclass
class CameraCalibration(betterproto.Message):
    """Kamera-spezifische Metadaten"""

    sensor_name: str = betterproto.string_field(1)
    # z.B. Intrinsic-Matrix (3×3 row-major)
    intrinsic: List[float] = betterproto.double_field(2)


@dataclass
class CameraFrame(betterproto.Message):
    """Eine einzelne Kamera-Aufnahme"""

    sensor_name: str = betterproto.string_field(1)
    frame_timestamp_ns: int = betterproto.uint64_field(2)
    width: int = betterproto.uint32_field(3)
    height: int = betterproto.uint32_field(4)
    encoding: str = betterproto.string_field(5)
    image_data: bytes = betterproto.bytes_field(6)
    calibration: "CameraCalibration" = betterproto.message_field(7)


@dataclass
class LidarScan(betterproto.Message):
    """Alle Daten eines Sensors pro Sweep/Zeitstempel"""

    laser_name: "LaserName" = betterproto.enum_field(1)
    scan_timestamp_ns: int = betterproto.uint64_field(2)
    # Hier die gekapselte Punktwolke:
    pointcloud: data.PointCloud = betterproto.message_field(3)
    # Kalibrierungs-Infos
    calibration: common.SensorCalibration = betterproto.message_field(4)
    # Objekte, die in diesem Scan detektiert wurden
    object_list: List[label.ObjectBBox] = betterproto.message_field(5)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: a42/common/calibration.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto


@dataclass
class SensorCalibration(betterproto.Message):
    sensor_name: str = betterproto.string_field(1)
    extrinsic: List[float] = betterproto.float_field(2)
    vertical_fov: float = betterproto.float_field(3)
    horizontal_fov: float = betterproto.float_field(4)
    vertical_scanlines: int = betterproto.uint32_field(5)
    horizontal_scanlines: int = betterproto.uint32_field(6)
    horizontal_angle_spacing: float = betterproto.float_field(7)
    beam_altitude_angles: List[float] = betterproto.float_field(8)
    beam_azimuth_angles: List[float] = betterproto.float_field(9)
    frame_mode: str = betterproto.string_field(10)
    scan_pattern: str = betterproto.string_field(11)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: a42/label/object.proto
# plugin: python-betterproto
from dataclasses import dataclass

import betterproto

from . import data


@dataclass
class Position(betterproto.Message):
    x: float = betterproto.float_field(1)
    y: float = betterproto.float_field(2)
    z: float = betterproto.float_field(3)


@dataclass
class Dimensions(betterproto.Message):
    x: float = betterproto.float_field(1)
    y: float = betterproto.float_field(2)
    z: float = betterproto.float_field(3)


@dataclass
class Orientation(betterproto.Message):
    x: float = betterproto.float_field(1)
    y: float = betterproto.float_field(2)
    z: float = betterproto.float_field(3)
    w: float = betterproto.float_field(4)


@dataclass
class Velocity(betterproto.Message):
    x: float = betterproto.float_field(1)
    y: float = betterproto.float_field(2)
    z: float = betterproto.float_field(3)


@dataclass
class ObjectBBox(betterproto.Message):
    id: int = betterproto.uint32_field(1)
    timestamp_ns: int = betterproto.uint64_field(2)
    position: "Position" = betterproto.message_field(3)
    dimension: "Dimensions" = betterproto.message_field(4)
    orientation: "Orientation" = betterproto.message_field(5)
    velocity: "Velocity" = betterproto.message_field(6)
    pointcloud: data.PointCloud = betterproto.message_field(7)
    obj_class: str = betterproto.string_field(8)
    obj_class_score: float = betterproto.float_field(9)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: a42/frame.proto
# plugin: python-betterproto
from dataclasses import dataclass
from typing import List

import betterproto

from . import sensors


@dataclass
class Frame(betterproto.Message):
    """Frame fasst nur noch mehrere Sensor‐Scans zusammen."""

    frame_timestamp_ns: int = betterproto.uint64_field(1)
    lidars: List[sensors.LidarScan] = betterproto.message_field(2)
